:mod:`~turboctl.virtualpump.parameter_component`
================================================

.. automodule:: turboctl.virtualpump.parameter_component
    :no-members:
    :members: ParameterComponent, ExtendedParameter

.. autoclass:: turboctl.virtualpump.parameter_component.ExtendedParameters
    :show-inheritance:
    
.. ExtendedParameters inherits dict, so it is documented separately to display
   the inheritance. The :no-members: command must be used in automodule to
   suppress the automatic :members: command given in conf.py.
